[openib-general] [PATCH] ib_mad.h: Add bad_send_wr parameter to ib_mad_post_send()

Hal Rosenstock halr at voltaire.com
Mon Sep 6 16:18:56 PDT 2004


Add bad_send_wr parameter to ib_mad_post_send()
Also modified the ib_mad_send_wc (but not the recv one nor eliminated
the ib_mad_send_wr structure.

Index: ib_mad.h
===================================================================
--- ib_mad.h    (revision 739)
+++ ib_mad.h    (working copy)
@@ -163,13 +163,13 @@
 
 /**
  * ib_mad_send_wc - MAD send completion information.
  * @context - Context associated with the send MAD request.
request.
  * @status - Completion status.
  * @vendor_err - Optional vendor error information returned with a
failed
  *   request.
  */
 struct ib_mad_send_wc {
-       void                    *context;
+       u64                     wr_id;
        enum ib_wc_status       status;
        u32                     vendor_err;
 };
@@ -260,13 +260,15 @@
 int ib_mad_dereg(struct ib_mad_agent *mad_agent);
 
 /**
- * ib_mad_post_send - Posts a MAD to the send queue of the QP
associated
+ * ib_mad_post_send - Posts MAD(s) to the send queue of the QP
associated
  *   with the registered client.
  * @mad_agent - Specifies the associated registration to post the send
to.
- * @mad_send_wr - Specifies the information needed to send the MAD.
+ * @send_wr - Specifies the information needed to send the MAD(s).
+ * @bad_send_wr - Specifies the MAD on which an error was encountered.
  */
 int ib_mad_post_send(struct ib_mad_agent *mad_agent,
-                    struct ib_mad_send_wr *mad_send_wr);
+                    struct ib_send_wr *send_wr,
+                    struct ib_send_wr **bad_send_wr);
 
 /**
  * ib_mad_qp_redir - Registers a QP for MAD services.
@@ -163,13 +163,13 @@
 /**
  * ib_mad_send_wc - MAD send completion information.
- * @context - Context associated with the send MAD request.
+ * @wr_id - Work request identifier associated with the send MAD
request.
  * @status - Completion status.





More information about the general mailing list